@@ -3,16 +3,17 @@ context("IDN")
 test_that("IDN domain names",{
   # OSX does not support IDN by default :(
   skip_if_not(curl_version()$idn, "libcurl does not have libidn")
+  skip_on_cran()
 
-  malmo <- "http://www.malm\u00F6.se"
-  expect_is(curl::curl_fetch_memory(enc2utf8(malmo))$status_code, "integer")
-  expect_is(curl::curl_fetch_memory(enc2native(malmo))$status_code, "integer")
+  koln <- "http://www.köln.de"
+  expect_is(curl::curl_fetch_memory(enc2utf8(koln))$status_code, "integer")
+  expect_is(curl::curl_fetch_memory(enc2native(koln))$status_code, "integer")
 
-  con <- curl::curl(enc2utf8(malmo))
+  con <- curl::curl(enc2utf8(koln))
   expect_is(readLines(con, warn = FALSE), "character")
   close(con)
 
-  con <- curl::curl(enc2native(malmo))
+  con <- curl::curl(enc2native(koln))
   expect_is(readLines(con, warn = FALSE), "character")
   close(con)
 
@@ -24,6 +25,6 @@ test_that("IDN domain names",{
   close(con)
 
   # Something random that doesn't exist
-  wrong <- "http://\u043F\u0840\u0435\u0537\u0438\u0433\u0435\u043F\u0442.\u0440\u0444"
+  wrong <- "http://\u043F\u0440\u00F6\u0437\u0438\u0434\u0435\u043D\u0442.\u0440\u0444"
   expect_error(curl::curl_fetch_memory(enc2utf8(wrong)), 'resolve')
 })
